common

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 19, 2023 License: BSD-3-Clause, MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	DarkFormBG            = wcolor.Color(0x202020)
	DarkFormLighterBG     = wcolor.Color(0x272727)
	DarkButtonBG          = wcolor.Color(0x343434)
	DarkTextTitleFG       = wcolor.Color(0xEEEEEE)
	DarkTextFG            = wcolor.Color(0xDBDBD1)
	DarkTextLinkFG        = wcolor.Color(0x99EBFF)
	DarkSelectHoverBG     = wcolor.Color(0x162430)
	DarkSelectHighlightBG = wcolor.Color(0x143047)
)

Variables

This section is empty.

Functions

func IsDarkMode

func IsDarkMode() bool

IsDarkMode returns true if dark mode is enabled and allowed

func IsDarkModeChecked

func IsDarkModeChecked() bool

IsDarkModeChecked returns true if dark mode has been checked already. This can be ignored as it's set automatically

func SetDarkMode

func SetDarkMode(value bool)

SetDarkMode is used to set if dark mode is enabled. This is normally set by the OS automatically, but you can override it too

func SetDarkModeAllowed

func SetDarkModeAllowed(value bool)

SetDarkModeAllowed is used to allow dark mode. This should be called prior to initializing walk

func SetDarkModeChecked

func SetDarkModeChecked(value bool)

SetDarkModeChecked is used to set if dark mode has been checked. This can be ignored as it's set automatically

Types

This section is empty.

Jump to