package
Version:
v0.0.21
Opens a new window with list of versions in this module.
Published: Mar 15, 2025
License: BSD-3-Clause, MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 8
Opens a new window with list of known importers.
Documentation
¶
func CenterWindowOnScreen(window *MainWindow)
CenterWindowOnScreen will center the window on the screen
Source Files
¶
Click to show internal directories.
Click to hide internal directories.